.. yakc documentation master file, created by
   sphinx-quickstart on Tue Oct  8 22:45:14 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to yakc's documentation!
================================

.. toctree::
   :maxdepth: 2

   first
   kyotodb
   limitation


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

